@@ -3,6 +3,7 @@ from abc import ABCMeta, abstractmethod
 import tensorflow as tf
 from six import with_metaclass
 import numpy as np
+from py_common_util.common.annotations import print_exec_time
 from py_common_util.tensorflow.tf_utils import TFUtils
 import argparse
 import datetime, time
@@ -12,7 +13,6 @@ from collections import OrderedDict
 from skydl.model.constants import Constants
 from skydl.model.super_net import SuperNet
 from skydl.model.train_phase_enum import TrainPhaseEnum
-from py_common_util.common.common_utils import CommonUtils
 sys.path.append(os.path.abspath('%s/..' % sys.path[0]))
 
 
@@ -206,7 +206,7 @@ class SuperModel(with_metaclass(ABCMeta)):
         return SuperNet(self.name if self.name else 'super_net', self.parser_args)
 
     def get_model_checkpoint_dir(self):
-        model_checkpoint_dir = self.parser_args.model_checkpoint_path + "/" + self.model.name() + "/" + self.parser_args.model_version
+        model_checkpoint_dir = self.parser_args.saved_model_path + "/" + self.model.name() + "/" + self.parser_args.model_version
         if not os.path.exists(model_checkpoint_dir):
             os.makedirs(model_checkpoint_dir)
         return model_checkpoint_dir
@@ -267,7 +267,7 @@ class SuperModel(with_metaclass(ABCMeta)):
         """
         self.parser.add_argument('--init_from_saver', type=bool, default=True, metavar='N',
                             help='init from saved checkpoint')
-        self.parser.add_argument('--model_checkpoint_path', type=str, default=sys.path[0] + '/saved_model',
+        self.parser.add_argument('--saved_model_path', type=str, default=sys.path[0] + '/saved_model',
                             help='model checkpoint saved to path')
         self.parser.add_argument('--model_version', type=str, default='1',
                                  help='version number of the model')
@@ -460,8 +460,8 @@ class SuperModel(with_metaclass(ABCMeta)):
                         checkpoint = tf.train.get_checkpoint_state(
                             self.get_model_checkpoint_dir(),
                             latest_filename=self.latest_model_filename)
-                        if checkpoint and checkpoint.model_checkpoint_path:
-                            saver.restore(sess, checkpoint.model_checkpoint_path)
+                        if checkpoint and checkpoint.saved_model_path:
+                            saver.restore(sess, checkpoint.saved_model_path)
                             self.log.info("Restored and Init Session Variables from Saver......")
                         else:
                             self.log.info("*** Error Occurred in " + self.parser_args.train_phase + " phase(1), Can not find the model file: "
@@ -531,15 +531,15 @@ class SuperModel(with_metaclass(ABCMeta)):
                                              self.get_model_checkpoint_dir(),
                                              'graph.pbtxt',
                                              as_text=True)
-                        self.log.info("saved model file to: " + self.parser_args.model_checkpoint_path + "/" + self.model.name())
+                        self.log.info("saved model file to: " + self.parser_args.saved_model_path + "/" + self.model.name())
                         # 统计整个训练时间
                         duration = (time.time() - start_time) * 1000
                         self.log.info("training Duration(milliseconds)=%d, Optimization Finished!" % duration)
                 checkpoint = tf.train.get_checkpoint_state(
                     self.get_model_checkpoint_dir(),
                     latest_filename=self.latest_model_filename)
-                if checkpoint and checkpoint.model_checkpoint_path:
-                    saver.restore(sess, checkpoint.model_checkpoint_path)
+                if checkpoint and checkpoint.saved_model_path:
+                    saver.restore(sess, checkpoint.saved_model_path)
                 else:
                     self.log.info("*** Error For " + self.parser_args.train_phase
                           + " phase(2), can not find the model file: "
@@ -607,7 +607,7 @@ class SuperModel(with_metaclass(ABCMeta)):
         """python版的预测接口，返回预测结果"""
         return None
 
-    @CommonUtils.print_exec_time
+    @print_exec_time
     def inference(self, tfx_host_port="http://localhost:8501/", model_name=None, features_list=[]):
         """
         inference request to tf serving
@@ -777,7 +777,7 @@ class SuperModel(with_metaclass(ABCMeta)):
                             sess=None,
                             _x=None,
                             predict=None,
-                            model_checkpoint_path=None,
+                            saved_model_path=None,
                             data_record_name=None,
                             model_version='1'):
         """
@@ -800,11 +800,11 @@ class SuperModel(with_metaclass(ABCMeta)):
         --mount type=bind,source=/tony/pycharm_projects/deep_trading/saved_model/serving/models/kcws,target=/models/kcws \
         -e MODEL_NAME=kcws -t tensorflow/serving:1.13.0
         """
-        if model_checkpoint_path is None:
-            model_checkpoint_path = self.parser_args.model_checkpoint_path + '/serving/models'
+        if saved_model_path is None:
+            saved_model_path = self.parser_args.saved_model_path + '/serving/models'
         if data_record_name is None:
             data_record_name = self.model.name()
-        export_path_base = model_checkpoint_path + '/' + data_record_name
+        export_path_base = saved_model_path + '/' + data_record_name
         export_path = os.path.join(
             tf.compat.as_bytes(export_path_base),
             tf.compat.as_bytes(model_version))
@@ -888,7 +888,7 @@ class SuperModel(with_metaclass(ABCMeta)):
             checkpoint = tf.train.get_checkpoint_state(self.get_model_checkpoint_dir(),
                                                        latest_filename="model.ckpt")
             if checkpoint:
-                input_checkpoint = checkpoint.model_checkpoint_path
+                input_checkpoint = checkpoint.saved_model_path
         if output_graph is None:
             output_graph = self.get_model_checkpoint_dir() + '/freezed-model.pbtxt'
         if not gfile.Exists(input_graph):
