@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from dataclasses import dataclass
-from ray.experimental.streaming.communication import QueueConfig
+from skydl.ray.experimental.streaming.communication import QueueConfig
 
 
 class DefaultStreamingEnvConfig(object):
@@ -29,24 +29,8 @@ class DefaultStreamingSource(object):
         return None
 
 
-class StreamingRecord(object):
-    """
-    (old) A class used to streaming transformer
-    @:param tuple_value e.g. ("00700.HK", [open, high, low, close]) or ("ok",1), ("fail",0)
-    """
-    def __init__(self, tuple_value):
-        k, v = tuple_value
-        self.key = k
-        self.record = tuple_value
-
-    def get_value(self):
-        if self.record is None:
-            return None
-        return self.record[1]
-
-
 @dataclass
-class StreamingRecordDataClass(object):
+class StreamingRecord(object):
     """
     A class used to streaming transformer
     """
@@ -56,5 +40,5 @@ class StreamingRecordDataClass(object):
 
 
 if __name__ == '__main__':
-   obj = StreamingRecordDataClass("ok", "error", [12.1, 13.3, 11.00, 12.34])
+   obj = StreamingRecord("ok", "data", [12.1, 13.3, 11.00, 12.34])
    print(obj.type)
\ No newline at end of file
